@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *	$Id: camio.c,v 1.4 2000/09/27 14:41:36 akiyama Exp $
+ *	$Id: camio.c,v 1.5 2000/10/19 15:32:16 akiyama Exp $
  */
 
 #include <stdio.h>
@@ -180,10 +180,13 @@ scsi_error(csio)
 		ascq = 0;
 	}
 
-	if (skey == SSD_KEY_UNIT_ATTENTION && asc == 0x28 && ascq == 0) {
+	if (csio->cdb_io.cdb_bytes[0] == SCSI_TEST_UNIT_READY &&
+	    ((skey == SSD_KEY_UNIT_ATTENTION && asc == 0x28 && ascq == 0)
+	     || (skey == SSD_KEY_NOT_READY && asc == 0x3a && ascq == 0))) {
 		/*
-		 * Media had been changed!
-		 * This is not a really error.
+		 * Media had been changed, and
+		 * NOT READY, Medium not present.
+		 * These are not a really error.
 		 */
 		sts = ERR_NONE;
 	} else if (csio->cdb_io.cdb_bytes[0] == SCSI_VERIFY &&
@@ -226,7 +229,6 @@ test_unit_ready()
 
 	/* Disable freezing the device queue */
 	ccb->ccb_h.flags |= CAM_DEV_QFRZDIS;
-	ccb->ccb_h.flags |= CAM_PASS_ERR_RECOVER;
 
 	sts = cam_send_ccb(path, ccb);
 	if (sts < 0) {
